:py:mod:`random_number_generator_com`
=====================================

.. py:module:: random_number_generator_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Random Number Generator

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Trigger', 'Random Out']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'Numpy Function', 'a', 'b', 'c', 'd']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'list', 'str', 'str', 'str', 'str']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, ['randint: a=low, b=high, c=size, d=dtype', 'random: a=size, b=dtype, c=out', 'bytes:...

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: random_number_generator_com
   

   

